@@ -1,6 +1,6 @@
 package XML::Writer::Nest;
 
-our $VERSION = '0.08';
+our $VERSION = '1.0';
 
 use Moose;
 has 'tag'    => (isa => 'Str', is => 'ro', required => 1);
@@ -206,6 +206,15 @@ the desired XML output.
 
 Terrence Brannon, C<< <metaperl at gmail.com> >>
 
+=head1 SEE ALSO
+
+=head2 "Constructive Use of Destructors"
+
+L<http://www.metaperl.org/publications>
+
+This talk to the Columbus, OH Perl mongers discusses XML::Writer::Nest in detail.
+
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-xml-writer-nest at rt.cpan.org>, or through
